#
# spec file for package python-sphinxcontrib-applehelp
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif
%{?sle15_python_module_pythons}
Name:           python-sphinxcontrib-applehelp%{psuffix}
Version:        2.0.0
Release:        1.2
Summary:        Sphinx extension which outputs Apple help books
License:        BSD-2-Clause
Group:          Development/Languages/Python
URL:            https://github.com/sphinx-doc/sphinxcontrib-applehelp
Source:         https://files.pythonhosted.org/packages/source/s/sphinxcontrib_applehelp/sphinxcontrib_applehelp-%{version}.tar.gz
BuildRequires:  %{python_module flit-core}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  gettext
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%if %{with test}
BuildRequires:  %{python_module Sphinx >= 5.0}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module sphinxcontrib-applehelp >= %{version}}
%endif
%python_subpackages

%description
sphinxcontrib-applehelp is a sphinx extension which outputs Apple help books

%prep
%setup -q -n sphinxcontrib_applehelp-%{version}

%build
%pyproject_wheel

%install
%if !%{with test}
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.rst CHANGES.rst
%license LICENCE.rst
%dir %{python_sitelib}/sphinxcontrib
%{python_sitelib}/sphinxcontrib/applehelp
%{python_sitelib}/sphinxcontrib_applehelp-%{version}*-info
%endif

%changelog
* Sun Sep  8 2024 Dirk Müller <dmueller@suse.com>
- update to 2.0.0:
  * Adopt Ruff
  * Tighten MyPy settings
  * Update GitHub actions versions
* Sun Jan 14 2024 Dirk Müller <dmueller@suse.com>
- update to 1.0.8:
  * Remove Sphinx as a required dependency, as circular
    dependencies may cause failure with package managers that
    expect a directed acyclic graph (DAG) of dependencies.
* Tue Aug 29 2023 Matej Cepl <mcepl@suse.com>
- Clean up the SPEC file
* Mon Aug 28 2023 Markéta Machová <mmachova@suse.com>
- Update to 1.0.7
  * Drop support for Python 3.8
  * Raise minimum required Sphinx version to 5.0
  * Fix tests for Sphinx 7.1 and below
* Fri Apr 21 2023 Dirk Müller <dmueller@suse.com>
- add sle15_python_module_pythons (jsc#PED-68)
* Thu Apr 13 2023 Matej Cepl <mcepl@suse.com>
- Make calling of %%{sle15modernpython} optional.
* Mon Mar  6 2023 Dirk Müller <dmueller@suse.com>
- update to 1.0.4:
  * Fix package name
  * Drop Python 3.8 and lower
  * Fix deprecation warnings from Sphinx 6.1
* Fri Mar  6 2020 pgajdos@suse.com
- version update to 1.0.2
  * Fix package metadata
* Tue Jun  4 2019 Tomáš Chvátal <tchvatal@suse.com>
- Initial commit, needed by Sphinx
